# Relations Between Applications and Hardware/Software Items
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/relations-between-applications-and-hardware-software-items#overview)
  * [Relation Types](https://help.sap.com/docs/leanix/ea/relations-between-applications-and-hardware-software-items#relation-types)
  * [Configuring Relation Mapping](https://help.sap.com/docs/leanix/ea/relations-between-applications-and-hardware-software-items#configuring-relation-mapping)


Configure how the ServiceNow integration detects relations between applications and hardware/software items.
